==> ump-0.8.3.2-src.tar.bz2: ump-0.8.3.2/src/picture2gtk.h <==

/*
 *  picture2gtk - makes pictures viewable using GTK+
 *  Copyright (c) 2003-2005 by Mattias Hultgren <mattias_hultgren@tele2.se>
 *
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

/*
  This object make the picture_h::picture-object viewable using GTK+2.0

v1.0.4  2004-11-13 - 2004-12-19
------

	Event-function-pointers are public
	Fixed om compiler warnings

v1.0.3  2004-07-14  &  2004-08-14 - 2004-09-12
------

	Removed all appearance of Thrower
	Added Copy-constructor, (width,height,color)-constructor
	Renamed a lot of functions
	Added gdkcolor_to_colorrgb, colorrgb_to_gdkcolor
	Changed so that the button is sent also to mousedown and mouseup
	Added force_expose, force_expose_line, force_expose_col

v1.0.2  2004-06-15
------

	Fixed a few bugs

v1.0.1  2004-04-20
------

	Added events: mousemove, mousedown, mouseup

v1.0.0  2003-12-10 - 2003-12-18  &  2004-03-20 - 2004-03-25
------

	Basic functions works.

*/

#ifndef PICTURE2GTK_H_
#define PICTURE2GTK_H_

#define PICTURE2GTK_H_VERSION "v1.0.4"
#define PICTURE2GTK_H_DATE    "2003-12 - 2004-12"

#include <gtk/gtk.h>
#include "vartypes.h"
#include "picture.h"


void gdkcolor_to_colorrgb( const GdkColor &src, picture_h::colorrgb &dest );
void colorrgb_to_gdkcolor( const picture_h::colorrgb &src, GdkColor &dest );


class picture2gtk : public picture_h::picture
{
private:
	struct
	{
		int32 width,height;

		int32 buffersize;
		guchar *buffer;

		GtkWidget *drawarea;
	}raw;

	friend gboolean picture2gtk_expose(GtkWidget *widget,GdkEventExpose *event,gpointer user_data);
	friend gboolean picture2gtk_destroy(GtkWidget *widget,gpointer user_data);
	friend gboolean picture2gtk_mousemove(GtkWidget *widget,GdkEventMotion *event,gpointer user_data);
	friend gboolean picture2gtk_mousedown(GtkWidget *widget,GdkEventButton *event,gpointer user_data);
	friend gboolean picture2gtk_mouseup(GtkWidget *widget,GdkEventButton *event,gpointer user_data);

	void set_raw_size(int32 newwidth,int32 newheight) throw(error_obj);

public:
	// button  1=left  2=middle  3=right  4=?  5=?
	void (*mousemove_func)( const picture2gtk *src, int32 x, int32 y);
	void (*mousedown_func)( const picture2gtk *src, int32 x, int32 y, int32 button);
	void (*mouseup_func)  ( const picture2gtk *src, int32 x, int32 y, int32 button);

	picture2gtk();
	picture2gtk(const picture2gtk &src) throw(error_obj);
	picture2gtk(int32 newwidth, int32 newheight, const picture_h::colorrgb &newcolor) throw(error_obj);
	~picture2gtk();

	void set_size(int32 newwidth,int32 newheight) throw(error_obj);

	// WARNING: this pointer may (likely) get illegal after a call to set_size, update or update_from
	// so a tip is.. don't save the pointer get a new one
	// you mustn't delete [] pointer...the object will handle this
	inline guchar * get_intern_buffer(void) { return raw.buffer; }

	void update(void) throw(error_obj);

	void update_from(const picture_h::picture &src) throw(error_obj);

	void connect_to_drawing_area(GtkWidget *newdrawarea);
	void disconnect_from_drawing_area(void);
	void force_expose(void);
	void force_expose_line(int32 line);
	void force_expose_col(int32 col);

	void operator=(const picture2gtk &src) throw(error_obj);

	// this function leaves the mousemove, mousedown & mouseup as they were
	void operator=(const picture_h::picture &src) throw(error_obj);
};

typedef picture2gtk * picture2gtk_ptr;

#endif

==> ump-0.8.4-src.tar.bz2: ump-0.8.4/src/picture2gtk.h <==

/*
 *  picture2gtk - makes pictures viewable using GTK+
 *  Copyright (c) 2003-2006 by Mattias Hultgren <mattias_hultgren@tele2.se>
 *
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; version 2 of the License.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public
 *   License along with this program; if not, write to the Free Software
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 */

/*
  This object make the picture_h::picture-object viewable using GTK+2.0

*/

#ifndef PICTURE2GTK_H_
#define PICTURE2GTK_H_

#define PICTURE2GTK_H_VERSION "v6"
#define PICTURE2GTK_H_DATE    "2003-12 - 2006-04"

#include <gtk/gtk.h>
#include "vartypes.h"
#include "picture.h"


void gdkcolor_to_colorrgb( const GdkColor &src, picture_h::colorrgb &dest );
void colorrgb_to_gdkcolor( const picture_h::colorrgb &src, GdkColor &dest );


class picture2gtk : public picture_h::picture
{
private:
	struct
	{
		int32 width,height;

		int32 buffersize;
		guchar *buffer;

		GtkWidget *drawarea;
	}raw;

	friend gboolean picture2gtk_expose(GtkWidget *widget,GdkEventExpose *event,gpointer user_data);
	friend gboolean picture2gtk_destroy(GtkWidget *widget,gpointer user_data);
	friend gboolean picture2gtk_mousemove(GtkWidget *widget,GdkEventMotion *event,gpointer user_data);
	friend gboolean picture2gtk_mousedown(GtkWidget *widget,GdkEventButton *event,gpointer user_data);
	friend gboolean picture2gtk_mouseup(GtkWidget *widget,GdkEventButton *event,gpointer user_data);

	void set_raw_size(int32 newwidth,int32 newheight) throw(error_obj);

public:
	// button  1=left  2=middle  3=right  4=?  5=?
	void (*mousemove_func)( const picture2gtk *src, int32 x, int32 y);
	void (*mousedown_func)( const picture2gtk *src, int32 x, int32 y, int32 button);
	void (*mouseup_func)  ( const picture2gtk *src, int32 x, int32 y, int32 button);

	picture2gtk();
	picture2gtk(const picture2gtk &src) throw(error_obj);
	picture2gtk(int32 newwidth, int32 newheight, const picture_h::colorrgb &newcolor) throw(error_obj);
	virtual ~picture2gtk();

	void set_size(int32 newwidth,int32 newheight) throw(error_obj);

	// WARNING: this pointer may (likely) get illegal after a call to set_size, update or update_from
	// so a tip is.. don't save the pointer get a new one
	// you mustn't delete [] pointer...the object will handle this
	inline guchar * get_intern_buffer(void) { return raw.buffer; }

	void update(void) throw(error_obj);

	void update_from(const picture_h::picture &src) throw(error_obj);

	void connect_to_drawing_area(GtkWidget *newdrawarea);
	void disconnect_from_drawing_area(void);
	void force_expose(void);
	void force_expose_line(int32 line);
	void force_expose_col(int32 col);

	void operator=(const picture2gtk &src) throw(error_obj);

	// this function leaves the mousemove, mousedown & mouseup as they were
	void operator=(const picture_h::picture &src) throw(error_obj);
};

typedef picture2gtk * picture2gtk_ptr;

#endif
